Package: fusen
Title: Build a Package from Rmarkdown Files
Version: 0.7.2
Authors@R: c(
    person("Sebastien", "Rochette", , "sebastienrochettefr@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0002-1565-9313", "creator")),
    person("Vincent", "Guyader", , "vincent@thinkr.fr", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-0671-9270")),
    person("Yohann", "Mansiaux", , "yohann.mansiaux@gmail.com", role = "aut"),
    person("ThinkR", role = "cph")
  )
Description: Use Rmarkdown First method to build your package. Start your
    package with documentation, functions, examples and tests in the same
    unique file. Everything can be set from the Rmarkdown template file
    provided in your project, then inflated as a package. Inflating the
    template copies the relevant chunks and sections in the appropriate
    files required for package development.
License: MIT + file LICENSE
URL: https://thinkr-open.github.io/fusen/,
        https://github.com/Thinkr-open/fusen
Depends: R (>= 3.5.0)
Imports: attachment, cli, desc, devtools, glue, here (>= 1.0.0),
        lightparser, magrittr, methods, pkgload, roxygen2, stats,
        stringi, tibble, tidyr, tools, usethis (>= 2.0.0), utils, yaml
Suggests: covr, gert, knitr, rcmdcheck, rmarkdown, rstudioapi, styler,
        testthat (>= 3.2.0), withr
VignetteBuilder: knitr
Config/fusen/version: 0.7.0
Config/testthat/edition: 3
Config/testthat/parallel: false
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-08-04 13:50:07 UTC; PC
Author: Sebastien Rochette [aut] (ORCID:
    <https://orcid.org/0000-0002-1565-9313>, creator),
  Vincent Guyader [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0671-9270>),
  Yohann Mansiaux [aut],
  ThinkR [cph]
Maintainer: Vincent Guyader <vincent@thinkr.fr>
Repository: CRAN
Date/Publication: 2025-08-29 16:00:08 UTC
Built: R 4.6.0; ; 2026-04-25 13:01:04 UTC; unix
