# Generated by roxygen2: do not edit by hand

export("%>%")
export(add_additional)
export(add_dev_history)
export(add_flat_template)
export(add_full)
export(add_fusen_chunks)
export(add_minimal_flat)
export(add_minimal_package)
export(check_not_registered_files)
export(create_fusen)
export(deprecate_flat_file)
export(draw_package_structure)
export(fill_description)
export(get_all_created_funs)
export(get_package_structure)
export(inflate)
export(inflate_all)
export(inflate_all_no_check)
export(init_share_on_github)
export(list_flat_files)
export(load_flat_functions)
export(register_all_to_config)
export(rename_flat_file)
export(sepuku)
importFrom(attachment,att_amend_desc)
importFrom(cli,cat_rule)
importFrom(cli,cli_abort)
importFrom(cli,cli_alert_danger)
importFrom(cli,cli_alert_info)
importFrom(cli,cli_alert_success)
importFrom(cli,cli_alert_warning)
importFrom(devtools,check)
importFrom(glue,glue)
importFrom(magrittr,"%>%")
importFrom(methods,formalArgs)
importFrom(pkgload,unload)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(stringi,stri_trans_general)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tools,file_path_sans_ext)
importFrom(utils,getFromNamespace)
importFrom(utils,osVersion)
importFrom(utils,read.csv)
importFrom(utils,write.csv)
importFrom(yaml,read_yaml)
importFrom(yaml,write_yaml)
