---
title: "dev_history.Rmd empty"
output: html_document
editor_options: 
  chunk_output_type: console
---

```{r development, include=FALSE}
library(testthat)
```

```{r development-1}
# Load already included functions
pkgload::load_all(export_all = FALSE)
```

# My function

```{r function}

```

```{r examples}

```

```{r tests}
test_that("my_function works properly", {

})
```

<!-- # Inflate your package -->

<!-- You're one inflate from paper to box. -->
<!-- Build your package from this very Rmd using `fusen::inflate()` in the `development` chunk below. -->

```{r development-inflate, eval=FALSE}
# Run but keep eval=FALSE to avoid infinite loop
# Execute in the console directly
fusen::inflate(flat_file = "dev/dev_history.Rmd", vignette_name = "Additional")
```

<!-- - Verify your `"DESCRIPTION"` file has been updated -->
<!-- - Verify your function is in `"R/"` directory -->
<!-- - Verify your test is in `"tests/testthat/"` directory -->
<!-- - Verify this Rmd appears in `"vignettes/"` directory -->
