---
title: "dev_history.Rmd for working package"
output: html_document
editor_options: 
  chunk_output_type: console
---

```{r development, include=FALSE}
library(testthat)
```

# No roxygen with example and chunk named `fun-`

```{r fun-norox2}
my_norox2 <- function(x) {
  x + 10
}
```

```{r examples-norox2}
my_norox2(10)
```

# There can be development actions

```{r development-1, eval=FALSE}
# Run but keep eval=FALSE to avoid infinite loop
# Execute in the console directly
fusen::inflate(flat_file = "dev/dev_history.Rmd")
```

