---
title: "dev_history.Rmd empty"
output: html_document
editor_options: 
  chunk_output_type: console
---

```{r development, include=FALSE}
library(testthat)
```

# My function

```{r function-1}

```

```{r examples-1}

```

```{r tests-1}

```

# My data doc

```{r function-doc}
#' cars
#'
#' data in 'datasets'.
#'
#' @format A data frame with 50 rows and 2 variables:
#' \describe{
#'   \item{ speed }{  numeric }
#'   \item{ dist }{  numeric }
#' }
#' @source Ezekiel, M. (1930) Methods of Correlation Analysis. Wiley.
"cars"
```

# My pkg doc

```{r function-pkgdoc}
#' @keywords internal
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
## usethis namespace: end
NULL
```

# .onLoad function

```{r fun-onload}
# Lancement de message at start
#' @noRd
#'
.onLoad <- function(libname, pkgname) {
        the_message()
}

the_message <- function() {
  packageStartupMessage("hello")
}
```

# Internal variables

```{r function-internal}
colors <- c("#FFFFFF", "#F0F0F0")
```


```{r development-1, eval=FALSE}
# Run but keep eval=FALSE to avoid infinite loop
# Execute in the console directly
fusen::inflate(flat_file = "dev/dev_history.Rmd")
```
